Provides functionality for procedural text generation.
Structs
- RGrammar
- A replacement grammar.
- RGrammar
Expansion - The result of expanding a grammar.
- RGrammar
Node - A single node in a grammar.
Enums
- RGrammar
Creation Error - Error returned when creating a grammar fails.
- RGrammar
Expand Error - Error returned when expanding a grammar fails.
- RGrammar
Parse Error - Error returned when parsing a grammar from a string fails.
Traits
- Parameter
Key - Types implementing this trait can be used as keys for parameters when expanding a grammar.
- TagKey
- Types implementing this trait can be used as keys for tags when expanding a grammar.