ParameterKey

Trait ParameterKey 

pub trait ParameterKey:
    Hash
    + Eq
    + Clone
    + Debug { }
Types implementing this trait can be used as keys for parameters when expanding a grammar.

This trait is automatically implemented on any type satisfying the constraints.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T> ParameterKey for T
where T: Hash + Eq + Clone + Debug,