pub trait TagKey:
Hash
+ Eq
+ Clone
+ Debug { }Expand description
Types implementing this trait can be used as keys for tags when expanding a grammar.
This trait is automatically implemented on any type satisfying the constraints.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".